@@ -7,7 +7,12 @@ struct Position {
 
 fn main() {
     // you can also delete this
-    x_log::init_once(Some(Options::default()));
+    x_log::init_once(Some(Options {
+        print_level: true,
+        timezone: Timezone::Local,
+        colored: true,
+        ..Default::default()
+    }));
 
     let file = file!();
 
